@@ -344,6 +344,9 @@
 #define __NR_userfaultfd	388
 #define __NR_membarrier		389
 #define __NR_mlock2		390
+#define __NR_copy_file_range	391
+#define __NR_preadv2	392
+#define __NR_pwritev2	393
 
 #define __ARM_NR_breakpoint	0x0f0001
 #define __ARM_NR_cacheflush	0x0f0002
@@ -351,8 +354,6 @@
 #define __ARM_NR_usr32		0x0f0004
 #define __ARM_NR_set_tls	0x0f0005
 
-/* Repeated with SYS_ prefix */
-
 #define SYS_restart_syscall	0
 #define SYS_exit	1
 #define SYS_fork	2
@@ -699,3 +700,6 @@
 #define SYS_userfaultfd	388
 #define SYS_membarrier		389
 #define SYS_mlock2		390
+#define SYS_copy_file_range	391
+#define SYS_preadv2	392
+#define SYS_pwritev2	393
